@@ -5,7 +5,7 @@ from dotenv import load_dotenv
 if __name__ == "__main__":
     load_dotenv()
     messenger = WhatsApp(token=getenv("TOKEN"),
-                         phone_number_id=getenv("PHONE_NUMBER_ID"))
+                         phone_number_id={1:"1234", 2: "5678"})
 
     response = messenger.send_button(
         recipient_id="255757xxxxxx",
@@ -30,4 +30,5 @@ if __name__ == "__main__":
                 ],
             },
         },
+        sender=1
     )
